@@ -10,19 +10,22 @@ from typing import Any, TypedDict
 from bleak.backends.device import BLEDevice
 from bleak.backends.scanner import AdvertisementData
 
+from .adv_parsers.air_purifier import process_air_purifier
 from .adv_parsers.blind_tilt import process_woblindtilt
 from .adv_parsers.bot import process_wohand
 from .adv_parsers.bulb import process_color_bulb
 from .adv_parsers.ceiling_light import process_woceiling
 from .adv_parsers.contact import process_wocontact
 from .adv_parsers.curtain import process_wocurtain
+from .adv_parsers.fan import process_fan
 from .adv_parsers.hub2 import process_wohub2
+from .adv_parsers.hub3 import process_hub3
 from .adv_parsers.hubmini_matter import process_hubmini_matter
 from .adv_parsers.humidifier import process_evaporative_humidifier, process_wohumidifier
 from .adv_parsers.keypad import process_wokeypad
 from .adv_parsers.leak import process_leak
 from .adv_parsers.light_strip import process_wostrip
-from .adv_parsers.lock import process_wolock, process_wolock_pro
+from .adv_parsers.lock import process_lock2, process_wolock, process_wolock_pro
 from .adv_parsers.meter import process_wosensorth, process_wosensorth_c
 from .adv_parsers.motion import process_wopresence
 from .adv_parsers.plug import process_woplugmini
@@ -32,6 +35,7 @@ from .adv_parsers.relay_switch import (
 )
 from .adv_parsers.remote import process_woremote
 from .adv_parsers.roller_shade import process_worollershade
+from .adv_parsers.vacuum import process_vacuum, process_vacuum_k
 from .const import SwitchbotModel
 from .models import SwitchBotAdvertisement
 
@@ -54,7 +58,7 @@ class SwitchbotSupportedType(TypedDict):
     manufacturer_data_length: int | None
 
 
-SUPPORTED_TYPES: dict[str, SwitchbotSupportedType] = {
+SUPPORTED_TYPES: dict[str | bytes, SwitchbotSupportedType] = {
     "d": {
         "modelName": SwitchbotModel.CONTACT_SENSOR,
         "modelFriendlyName": "Contact Sensor",
@@ -230,6 +234,84 @@ SUPPORTED_TYPES: dict[str, SwitchbotSupportedType] = {
         "func": process_hubmini_matter,
         "manufacturer_id": 2409,
     },
+    "~": {
+        "modelName": SwitchbotModel.CIRCULATOR_FAN,
+        "modelFriendlyName": "Circulator Fan",
+        "func": process_fan,
+        "manufacturer_id": 2409,
+    },
+    ".": {
+        "modelName": SwitchbotModel.K20_VACUUM,
+        "modelFriendlyName": "K20 Vacuum",
+        "func": process_vacuum,
+        "manufacturer_id": 2409,
+    },
+    "z": {
+        "modelName": SwitchbotModel.S10_VACUUM,
+        "modelFriendlyName": "S10 Vacuum",
+        "func": process_vacuum,
+        "manufacturer_id": 2409,
+    },
+    "3": {
+        "modelName": SwitchbotModel.K10_PRO_COMBO_VACUUM,
+        "modelFriendlyName": "K10+ Pro Combo Vacuum",
+        "func": process_vacuum,
+        "manufacturer_id": 2409,
+    },
+    "}": {
+        "modelName": SwitchbotModel.K10_VACUUM,
+        "modelFriendlyName": "K10+ Vacuum",
+        "func": process_vacuum_k,
+        "manufacturer_id": 2409,
+    },
+    "(": {
+        "modelName": SwitchbotModel.K10_PRO_VACUUM,
+        "modelFriendlyName": "K10+ Pro Vacuum",
+        "func": process_vacuum_k,
+        "manufacturer_id": 2409,
+    },
+    "*": {
+        "modelName": SwitchbotModel.AIR_PURIFIER,
+        "modelFriendlyName": "Air Purifier",
+        "func": process_air_purifier,
+        "manufacturer_id": 2409,
+    },
+    "+": {
+        "modelName": SwitchbotModel.AIR_PURIFIER,
+        "modelFriendlyName": "Air Purifier",
+        "func": process_air_purifier,
+        "manufacturer_id": 2409,
+    },
+    "7": {
+        "modelName": SwitchbotModel.AIR_PURIFIER_TABLE,
+        "modelFriendlyName": "Air Purifier Table",
+        "func": process_air_purifier,
+        "manufacturer_id": 2409,
+    },
+    "8": {
+        "modelName": SwitchbotModel.AIR_PURIFIER_TABLE,
+        "modelFriendlyName": "Air Purifier Table",
+        "func": process_air_purifier,
+        "manufacturer_id": 2409,
+    },
+    b"\x00\x10\xb9\x40": {
+        "modelName": SwitchbotModel.HUB3,
+        "modelFriendlyName": "Hub3",
+        "func": process_hub3,
+        "manufacturer_id": 2409,
+    },
+    "-": {
+        "modelName": SwitchbotModel.LOCK_LITE,
+        "modelFriendlyName": "Lock Lite",
+        "func": process_wolock,
+        "manufacturer_id": 2409,
+    },
+    b"\x00\x10\xa5\xb8": {
+        "modelName": SwitchbotModel.LOCK_ULTRA,
+        "modelFriendlyName": "Lock Ultra",
+        "func": process_lock2,
+        "manufacturer_id": 2409,
+    },
 }
 
 _SWITCHBOT_MODEL_TO_CHAR = {
@@ -278,10 +360,8 @@ def parse_advertisement_data(
             _mfr_id,
             model,
         )
-    except Exception as err:  # pylint: disable=broad-except
-        _LOGGER.exception(
-            "Failed to parse advertisement data: %s: %s", advertisement_data, err
-        )
+    except Exception:  # pylint: disable=broad-except
+        _LOGGER.exception("Failed to parse advertisement data: %s", advertisement_data)
         return None
 
     if not data:
@@ -310,6 +390,12 @@ def _parse_data(
             if model_data.get("manufacturer_data_length") == len(_mfr_data):
                 _model = model_chr
                 break
+    if (
+        _service_data
+        and len(_service_data) > 5
+        and _service_data[-4:] in SUPPORTED_TYPES
+    ):
+        _model = _service_data[-4:]
 
     if not _model:
         return None
