@@ -3,9 +3,11 @@
 from __future__ import annotations
 
 from ..enum import StrEnum
+from .air_purifier import AirPurifierMode
+from .fan import FanMode
 
 # Preserve old LockStatus export for backwards compatibility
-from .lock import LockStatus as LockStatus
+from .lock import LockStatus
 
 DEFAULT_RETRY_COUNT = 3
 DEFAULT_RETRY_TIMEOUT = 1
@@ -65,3 +67,28 @@ class SwitchbotModel(StrEnum):
     EVAPORATIVE_HUMIDIFIER = "Evaporative Humidifier"
     ROLLER_SHADE = "Roller Shade"
     HUBMINI_MATTER = "HubMini Matter"
+    CIRCULATOR_FAN = "Circulator Fan"
+    K20_VACUUM = "K20 Vacuum"
+    S10_VACUUM = "S10 Vacuum"
+    K10_VACUUM = "K10+ Vacuum"
+    K10_PRO_VACUUM = "K10+ Pro Vacuum"
+    K10_PRO_COMBO_VACUUM = "K10+ Pro Combo Vacuum"
+    AIR_PURIFIER = "Air Purifier"
+    AIR_PURIFIER_TABLE = "Air Purifier Table"
+    HUB3 = "Hub3"
+    LOCK_ULTRA = "Lock Ultra"
+    LOCK_LITE = "Lock Lite"
+
+
+__all__ = [
+    "DEFAULT_RETRY_COUNT",
+    "DEFAULT_RETRY_TIMEOUT",
+    "DEFAULT_SCAN_TIMEOUT",
+    "AirPurifierMode",
+    "FanMode",
+    "LockStatus",
+    "SwitchbotAccountConnectionError",
+    "SwitchbotApiError",
+    "SwitchbotAuthenticationError",
+    "SwitchbotModel",
+]
